aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/grpcpp
diff options
context:
space:
mode:
authorGravatar ncteisen <ncteisen@gmail.com>2018-06-28 18:26:22 -0700
committerGravatar ncteisen <ncteisen@gmail.com>2018-06-28 18:52:01 -0700
commita0a59537d2a8d25124cc1fe21cee10713012bceb (patch)
tree36690373d780978b94dce4ae62f0b7b95b2cd2b9 /include/grpcpp
parent8db7788d46fcdf9f35e8708e3b04bc4753f9f288 (diff)
s/CodegenGeneric/Raw/g
Diffstat (limited to 'include/grpcpp')
-rw-r--r--include/grpcpp/impl/codegen/rpc_service_method.h8
-rw-r--r--include/grpcpp/impl/codegen/service_type.h13
2 files changed, 10 insertions, 11 deletions
diff --git a/include/grpcpp/impl/codegen/service_type.h b/include/grpcpp/impl/codegen/service_type.h
index dc63b9dc21..a0bbd659e2 100644
--- a/include/grpcpp/impl/codegen/service_type.h
+++ b/include/grpcpp/impl/codegen/service_type.h
@@ -134,15 +134,14 @@ class Service {
internal::RpcServiceMethod::AsyncType::ASYNC);
}
- void MarkMethodCodegenGeneric(int index) {
+ void MarkMethodRaw(int index) {
// This does not have to be a hard error, however no one has approached us
// with a use case yet. Please file an issue if you believe you have one.
- GPR_CODEGEN_ASSERT(
- methods_[index].get() != nullptr &&
- "Cannot mark the method as 'codegen generic' because it has already "
- "been marked as 'generic'.");
+ GPR_CODEGEN_ASSERT(methods_[index].get() != nullptr &&
+ "Cannot mark the method as 'raw' because it has already "
+ "been marked as 'generic'.");
methods_[index]->SetServerAsyncType(
- internal::RpcServiceMethod::AsyncType::CODEGEN_GENERIC);
+ internal::RpcServiceMethod::AsyncType::RAW);
}
void MarkMethodGeneric(int index) {
@@ -151,7 +150,7 @@ class Service {
GPR_CODEGEN_ASSERT(
methods_[index]->handler() != nullptr &&
"Cannot mark the method as 'generic' because it has already been "
- "marked as 'async' or 'codegen generic'.");
+ "marked as 'async' or 'raw'.");
methods_[index].reset();
}
diff --git a/include/grpcpp/impl/codegen/rpc_service_method.h b/include/grpcpp/impl/codegen/rpc_service_method.h
index 0f26cbe485..92c66bbf15 100644
--- a/include/grpcpp/impl/codegen/rpc_service_method.h
+++ b/include/grpcpp/impl/codegen/rpc_service_method.h
@@ -67,7 +67,7 @@ class RpcServiceMethod : public RpcMethod {
enum class AsyncType {
UNSET,
ASYNC,
- CODEGEN_GENERIC,
+ RAW,
};
void set_server_tag(void* tag) { server_tag_ = tag; }
@@ -81,7 +81,7 @@ class RpcServiceMethod : public RpcMethod {
handler_.reset();
} else {
// this is not an error condition, as it allows users to declare a server
// like WithCodegenGenericMethod_foo<AsyncService>. However since it
// overwrites behavior, it should be logged.
gpr_log(
GPR_INFO,
@@ -104,8 +104,8 @@ class RpcServiceMethod : public RpcMethod {
return "unset";
case AsyncType::ASYNC:
return "async";
- case AsyncType::CODEGEN_GENERIC:
- return "codegen generic";
+ case AsyncType::RAW:
+ return "raw";
default:
GPR_UNREACHABLE_CODE(return "unknown");
}
@@ -81,7 +81,7 @@ class RpcServiceMethod : public RpcMethod {
} else {
// this is not an error condition, as it allows users to declare a server
- // like WithCodegenGenericMethod_foo<AsyncService>. However since it
+ // like WithRawMethod_foo<AsyncService>. However since it
// overwrites behavior, it should be logged.
gpr_log(